useDynLib(IsingSampler)
export(IsingSampler)
export(IsingSumLikelihood)
export(IsingLikelihood)
export(IsingStateProb)
importFrom("plyr","ddply","alply")
import(Rcpp)
export(LinTransform)
import(magrittr)
export(EstimateIsing)
export(IsingPL)
import(nnet)
export(EstimateIsing)
export(EstimateIsingPL)
export(EstimateIsingUni)
export(EstimateIsingBi)
export(EstimateIsingLL)
import(dplyr)
#export(NodeInformation)
export(IsingEntrophy)
importFrom("stats", "binomial", "coef", "glm", "loglin", "nlm")