# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

IsingProcess <- function(nSample, graph, thresholds, beta, responses, delta = NULL) {
    .Call('_IsingSampler_IsingProcess', PACKAGE = 'IsingSampler', nSample, graph, thresholds, beta, responses, delta)
}

IsingSamplerCpp <- function(n, graph, thresholds, beta, nIter, responses, exact, constrain, delta = NULL) {
    .Call('_IsingSampler_IsingSamplerCpp', PACKAGE = 'IsingSampler', n, graph, thresholds, beta, nIter, responses, exact, constrain, delta)
}

H <- function(J, s, h, delta = NULL) {
    .Call('_IsingSampler_H', PACKAGE = 'IsingSampler', J, s, h, delta)
}

f <- function(Y, J, h, delta = NULL) {
    .Call('_IsingSampler_f', PACKAGE = 'IsingSampler', Y, J, h, delta)
}

Hvec <- function(s, Theta, N) {
    .Call('_IsingSampler_Hvec', PACKAGE = 'IsingSampler', s, Theta, N)
}

PseudoLikelihood <- function(x, graph, thresholds, beta, responses, logis) {
    .Call('_IsingSampler_PseudoLikelihood', PACKAGE = 'IsingSampler', x, graph, thresholds, beta, responses, logis)
}

